[![CodeFactor](https://www.codefactor.io/repository/github/codelighthouse/sdk-python/badge)](https://www.codefactor.io/repository/github/codelighthouse/sdk-python)

# CodeLighthouse Python SDK

Quick Links |
--- |
[Documentation](https://docs.codelighthouse.io/docs/sdk-python) |
[PyPi](https://pypi.org/project/CodeLighthouse/) |
[Homepage](https://codelighthouse.io) |

Codelighthouse helps you catch errors in your application in real time and immediately notifies code owners.

We know your customers are important to you.  Codelighthouse helps you minimize error impact by improving your developer's
response time to mission-critical issues that arise through the use of your software.  As soon as an error occurs, the
developer responsible for maintaining that code is notified via his integration of choice.  This removes the need for 
excess support infrastructure within your organization.